==> ejc-technologymanage-api-3.0.0-20241213.082939-48-sources.jar: com/ejianc/business/tech/vo/TechAchieveVO.java <==
package com.ejianc.business.tech.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 技术创新推广成果
 * 
 * @author generator
 * 
 */
public class TechAchieveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String achieveName; // 成果名称
    private String achieveCode; // 成果编号
    private Long achieveOrg; // 成果来源
    private String achieveOrgName; // 成果来源单位名称
    private String truePath;//图片真实地址

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getAchieveName() {
        return achieveName;
    }

    public void setAchieveName(String achieveName) {
        this.achieveName = achieveName;
    }
    public String getAchieveCode() {
        return achieveCode;
    }

    public void setAchieveCode(String achieveCode) {
        this.achieveCode = achieveCode;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getAchieveOrg() {
        return achieveOrg;
    }
    @ReferDeserialTransfer
    public void setAchieveOrg(Long achieveOrg) {
        this.achieveOrg = achieveOrg;
    }

    public String getAchieveOrgName() {
        return achieveOrgName;
    }

    public void setAchieveOrgName(String achieveOrgName) {
        this.achieveOrgName = achieveOrgName;
    }

    public String getTruePath() {
        return truePath;
    }

    public void setTruePath(String truePath) {
        this.truePath = truePath;
    }
}

==> ejc-technologymanage-api-3.0.0-20251009.061221-54-sources.jar: com/ejianc/business/tech/vo/TechAchieveVO.java <==
package com.ejianc.business.tech.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 技术创新推广成果
 * 
 * @author generator
 * 
 */
public class TechAchieveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private String achieveName; // 成果名称
    private String achieveCode; // 成果编号
    private Long achieveOrg; // 成果来源
    private String achieveOrgName; // 成果来源单位名称
    private String truePath;//图片真实地址
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Date serviceDate; // 业务日期

    private List<TechAchieveZiVO> techAchieveZiList = new ArrayList<>(); // 技术创新推广成果子表
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getAchieveName() {
        return achieveName;
    }

    public void setAchieveName(String achieveName) {
        this.achieveName = achieveName;
    }
    public String getAchieveCode() {
        return achieveCode;
    }

    public void setAchieveCode(String achieveCode) {
        this.achieveCode = achieveCode;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getAchieveOrg() {
        return achieveOrg;
    }
    @ReferDeserialTransfer
    public void setAchieveOrg(Long achieveOrg) {
        this.achieveOrg = achieveOrg;
    }

    public String getAchieveOrgName() {
        return achieveOrgName;
    }

    public void setAchieveOrgName(String achieveOrgName) {
        this.achieveOrgName = achieveOrgName;
    }

    public String getTruePath() {
        return truePath;
    }

    public void setTruePath(String truePath) {
        this.truePath = truePath;
    }
}
